@@ -4,10 +4,10 @@
  * Blowfish Home Page: http://www.counterpane.com/
  *
  * License:
- * This code is in the public domain under the GNU public license
+ * This code is in the 'public domain' (*) under the GNU public license
  * for use with the virtual private network daemon (vpnd).
  * The copyright holder will however retain the copyright.
- * In addition to vpnd this code is put in the public domain
+ * In addition to vpnd this code is put in the 'public domain' (*)
  * for all GPL/LGPL based open source software products.
  * For all other software products please contact astmail@yahoo.com
  * for a license agreement. There is no guarantee for the fitness
@@ -16,6 +16,7 @@
  * Distribution and use of this code is explicitly granted provided
  * that the above header is not modified and the above conditions
  * are met.
+ * (*) 'public domain' is used here in the sense of the Wassenaar treaty.
  *
  * This implementation is tuned for speed.
  *
@@ -338,14 +339,15 @@ static WORD32 pi[BLOWFISH_SCHEDULESIZE]=
  * 128 bit key. Otherwise simply just don't encrypt...
  */
 
-void FASTCALL blowfish_key_schedule(WORD08 *key,WORD32 length,WORD32 *schedule)
+void CRYPTOCALL blowfish_key_schedule(WORD08 *key,WORD32 length,
+	WORD32 *schedule)
 {
-	register WORD32 l;	/* byte to long conversion and Xl of Blowfish	*/
-	register WORD32 r;	/* index and Xr of Blowfish			*/
-	register WORD32 *p;	/* Pn of Blowfish				*/
-	register WORD32 *s;	/* Sm,n of Blowfish				*/
-	WORD32 *x;		/* roving pointer for schedule creation		*/
-	WORD32 i;		/* counter and index				*/
+	register WORD32 l;	/* byte to long conversion and Xl of Blowfish */
+	register WORD32 r;	/* index and Xr of Blowfish		      */
+	register WORD32 *p;	/* Pn of Blowfish			      */
+	register WORD32 *s;	/* Sm,n of Blowfish			      */
+	WORD32 *x;		/* roving pointer for schedule creation	      */
+	WORD32 i;		/* counter and index			      */
 
 
 	/* compiler forced memcpy() from pi[] to schedule[] */
@@ -381,37 +383,69 @@ void FASTCALL blowfish_key_schedule(WORD08 *key,WORD32 length,WORD32 *schedule)
 		/* do unwrapped rounds 1 to 16 */
 
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 		l^=*p++;
-		r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+		r^=((s[(l>>24)&0xff]
+		  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])
+		  +s[(l&0xff)|0x300];
 		r^=*p++;
-		l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+		l^=((s[(r>>24)&0xff]
+		  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])
+		  +s[(r&0xff)|0x300];
 
 		/* do final Ps */
 
@@ -486,37 +520,53 @@ void CRYPTOCALL blowfish_encrypt(WORD08 *data,WORD32 *schedule)
 	/* process P1 to P16 */
 
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p++;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p++;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 
 	/* process P17 and P18 */
 
@@ -605,37 +655,53 @@ void CRYPTOCALL blowfish_decrypt(WORD08 *data,WORD32 *schedule)
 	/* process P18 to P3 */
 
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 	l^=*u.p--;
-	r^=((s[(l>>24)&0xff]+s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
+	r^=((s[(l>>24)&0xff]
+	  +s[((l>>16)&0xff)|0x100])^s[((l>>8)&0xff)|0x200])+s[(l&0xff)|0x300];
 	r^=*u.p--;
-	l^=((s[(r>>24)&0xff]+s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
+	l^=((s[(r>>24)&0xff]
+	  +s[((r>>16)&0xff)|0x100])^s[((r>>8)&0xff)|0x200])+s[(r&0xff)|0x300];
 
 	/* process P2 and P1 */
 
