@@ -56,6 +56,9 @@
 #include <errno.h>
 #include "common.h"
 #include "blowfish.h"
+#include "md5.h"
+#include "sha1.h"
+#include "rmd160.h"
 
 /* special if _NSIG is not defined */
 
@@ -65,7 +68,7 @@
 
 /* special definitions, do not change!!! */
 
-#define VERSION "1.0.6"	/* current vpnd version number			  */
+#define VERSION "1.0.7"	/* current vpnd version number			  */
 #define MAXBLOCK 2048	/* largest block size transferred, do not change! */
 #define MAXIDLE 900	/* longest link idle time before link test	  */
 #define XON 0x11	/* XON (for escaping/filtering)			  */
@@ -181,7 +184,8 @@ WORD08 autoroute;			/* ifconfig adds route		*/
 WORD08 slip;				/* slip up flag			*/
 WORD08 cipher;				/* cipher to be used		*/
 WORD08 unused;				/* unused, spare for future use	*/
-WORD16 keysize;				/* key length in bytes		*/
+WORD08 mac;				/* message auth width 		*/
+WORD08 keysize;				/* key length in bytes		*/
 WORD16 threshold;			/* compression test threshold	*/
 WORD16 retry;				/* global retry delay		*/
 WORD16 keepalive;			/* send pings when idle		*/
@@ -223,6 +227,7 @@ WORD08 icmp_in[64];			/* ping receive buffer		*/
 struct sockaddr_in icmp_target;		/* remote address of slip link	*/
 struct sockaddr_in icmp_source;		/* remote address of slip link	*/
 WORD32 rtab[ROUTES][3];			/* additional routes		*/
+int lock;				/* serial line lock file handle	*/
 char *conffile;				/* default configuration file	*/
 char *randomdev;			/* random number device file	*/
 char *serialdev;			/* serial device to be used	*/
@@ -234,11 +239,23 @@ char *keyfile;				/* master key file		*/
 char *lkeyfile;				/* local ext. master key file	*/
 char *rkeyfile;				/* remote ext. master key file	*/
 WORD08 secret[XKEYSIZE];		/* shared secret		*/
+int hmacopt;				/* HMAC operation option	*/
+int hmacmode;				/* HMAC selection option	*/
+union
+{
+	MD5HMDATA md5;			/* preprocessed HMAC-MD5 key	*/
+	SHA1HMDATA sha1;		/* preprocessed HMAC-SHA1 key	*/
+	RMD160HMDATA rmd160;		/* preprocessed HMAC-RMD160 key	*/
+} hmkey;
+void (*macproc)(WORD08 *,WORD32,WORD08 *,void *); /* mac routine	*/
+void (*mackey)(WORD08 *,WORD32,void *); /* mac key generation routine	*/
 char peerdev[16];			/* peer priority route device	*/
 WORD32 peergate;			/* peer priority route gateway	*/
 WORD32 peerip;				/* peer ip for priority route	*/
 char *linkup;				/* pathname of linkup process	*/
 char *linkdown;				/* pathname of linkdown process	*/
+char *slipup;				/* pathname of slipup process	*/
+char *slipdown;				/* pathname of slipdown process	*/
 WORD08 piv[BLOWFISH_BLOCKSIZE];		/* user key iv			*/
 union
 {
@@ -277,6 +294,10 @@ extern WORD08 terminate;		/* termination request (signal)	*/
 extern int debug;			/* debug level			*/
 #endif
 
+extern void (*mactab[4])(WORD08 *,WORD32,WORD08 *,void *); /* mac procs	*/
+extern void (*macinit[4])(WORD08 *,WORD32,void *); /* mac key procs	*/
+extern WORD08 maclen[4];		/* message auth length		*/
+
 /* function prototypes for slip.c */
 
 extern int sliphandler(int,VPN *);
@@ -295,7 +316,7 @@ extern int oobrecv(VPN *);
 /* function prototypes for crypto.c */
 
 extern int getrandom(WORD08 *,WORD32,VPN *);
-extern void checksum(WORD08 *,WORD32,WORD08 *);
+extern void checksum(WORD08 *,WORD32,WORD08 *,void *);
 extern void encrypt_cfb_64_8(WORD08 *,WORD32,VPN *);
 extern void decrypt_cfb_64_8(WORD08 *,WORD32,VPN *);
 extern int datasend(WORD08 *,WORD32,VPN *);
@@ -311,7 +332,7 @@ extern int chgpasswd(VPN *);
 
 /* function prototypes for external.c */
 
-extern void doexec(char *);
+extern void doexec(char *,char *);
 
 /* function prototypes for tcp.c */
 
